import 'dart:developer';

import 'package:flutter/material.dart';
import 'package:hub/backend/schema/enums/enums.dart';
import 'package:hub/components/atomic_components/menu_button_item/menu_button_item_widget.dart';
import 'package:hub/components/atomic_components/menu_card_item/menu_card_item.dart';
import 'package:hub/components/molecular_components/menu_item/menu_item.dart';
import 'package:hub/components/molecular_components/option_selection_modal/option_selection_modal_widget.dart';
import 'package:hub/components/organism_components/menu_component/menu_component_widget.dart';
import 'package:hub/components/organism_components/menu_list_view_component/menu_list_view_component_model.dart';
import 'package:hub/components/organism_components/menu_staggered_view_component/menu_staggered_view_component_model.dart';
import 'package:hub/flutter_flow/flutter_flow_util.dart';
import 'package:hub/flutter_flow/nav/nav.dart';
import 'package:hub/shared/extensions/dialog_extensions.dart';
import 'package:hub/shared/helpers/license/license_helper.dart';
import 'package:hub/shared/helpers/storage/base_storage.dart';
import 'package:hub/shared/helpers/storage/storage_helper.dart';
import 'package:hub/shared/services/authentication/authentication_service.dart';
import 'package:material_symbols_icons/symbols.dart';

import '/components/organism_components/menu_list_view_component/menu_list_view_component_widget.dart';
import 'menu_component_widget.dart' show MenuComponentWidget;

class MenuComponentModel extends FlutterFlowModel<MenuComponentWidget> {
  final MenuView style;
  final MenuItem item;
  final bool expandable;
  final List<Module> menuOptions;

  MenuComponentModel(
      {required this.style,
      required this.item,
      required this.expandable,
      required this.menuOptions});

  bool isGrid = false;

  late MenuListViewComponentModel menuListViewComponentModel;
  late MenuStaggeredViewComponentModel menuStaggeredViewComponentModel;
  late VoidCallback safeSetState;
  List<MenuEntry?> menuEntries = [];

  @override
  void initState(BuildContext context) {
    menuListViewComponentModel =
        createModel(context, () => MenuListViewComponentModel());
    menuStaggeredViewComponentModel =
        createModel(context, () => MenuStaggeredViewComponentModel());
  }

  @override
  void dispose() {
    menuListViewComponentModel.dispose();
    menuStaggeredViewComponentModel.dispose();
  }

  Future<List<MenuEntry?>> generateMenuEntries(
      BuildContext context, MenuItem item, List<Module> options) async {
    List<MenuEntry?> entries = [];
    Future<MenuEntry?> addMenuEntry(
        IconData icon, String text, Function() action) async {
      entries.add(
        item == MenuItem.button
            ? MenuButtonWidget(
                icon: icon,
                action: action,
                title: text,
                safeSetState: safeSetState)
            : item == MenuItem.card
                ? MenuCardItem(
                    icon: icon,
                    action: action,
                    title: text,
                    safeSetState: safeSetState)
                : item == MenuItem.tile
                    ? MenuCardItem(
                        icon: icon,
                        action: action,
                        title: text,
                        safeSetState: safeSetState)
                    : null,
      );
      return null;
    }

    for (var opt in options) {
      String? v = await LicenseHelper().g(opt.value);
      log('Module: ${opt.value} - License: $v');
      switch (v) {
        case 'VISIVEL':
          await addMenuEntry(opt.icon, opt.name, () async {
            await open(context, opt.route);
          });
          break;
        case 'BLOQUEADO':
          await addMenuEntry(opt.icon, opt.name, () async {
            await DialogUnavailable.unavailableFeature(context);
          });
          break;
        case 'INVISIVEL':
          break;
        default:
          break;
      }
      safeSetState();
    }

    return entries;
  }

  Future open(BuildContext context, String link) async {
    context.push(
      link,
      extra: <String, dynamic>{
        kTransitionInfoKey: const TransitionInfo(
          hasTransition: false,
          transitionType: PageTransitionType.scale,
          alignment: Alignment.bottomCenter,
        ),
      },
    );
  }

  Future out(BuildContext context) async {
    final String title = FFLocalizations.of(context).getVariableText(
      ptText: 'Sair',
      enText: 'Logout',
    );
    final String content = FFLocalizations.of(context).getVariableText(
      ptText: 'Tem certeza que deseja sair?',
      enText: 'Are you sure you want to logout?',
    );
    showAlertDialog(context, title, content,
        () async => await AuthenticationService.signOut(context));
  }

  Future<void> Logout(BuildContext context) async {
    final String title = FFLocalizations.of(context).getVariableText(
      ptText: 'Sair',
      enText: 'Logout',
    );
    final String content = FFLocalizations.of(context).getVariableText(
      ptText: 'Tem certeza que deseja sair?',
      enText: 'Are you sure you want to logout?',
    );
    showAlertDialog(context, title, content,
        () async => await AuthenticationService.signOut(context));
  }

  Future settings(BuildContext context) async {
    context.push(
      '/preferencesSettings',
      extra: <String, dynamic>{
        kTransitionInfoKey: const TransitionInfo(
          hasTransition: false,
          transitionType: PageTransitionType.scale,
          alignment: Alignment.bottomCenter,
        ),
      },
    );
  }

  Future about(BuildContext context) async {
    context.push(
      '/aboutProperty',
      extra: <String, dynamic>{
        kTransitionInfoKey: const TransitionInfo(
          hasTransition: false,
          transitionType: PageTransitionType.scale,
          alignment: Alignment.bottomCenter,
        ),
      },
    );
  }
}
